@@ -1,11 +1,10 @@
 
 ic.icc <-
-function(ccc,dev,S,alpha){
+function(ccc,dev,S,alpha,m){
   
 se.ccc <- as.numeric(sqrt(dev%*%S%*%t(dev)))
-
-z<-0.5*log((1+ccc)/(1-ccc))
-se.z<-c(sqrt(  (se.ccc^2)/(((1+ccc)^2)*((1-ccc)^2))  ) )
+z<-ZF(ccc,m)
+se.z<-dZF(ccc,m)*se.ccc
 ic.z=z+c(-1,1)*qnorm(1-alpha/2)*se.z
 ic.icc=(exp(2*ic.z)-1)/(exp(2*ic.z)+1)
 result<-c(ccc,ic.icc,se.ccc,z,se.z)
